@@ -1,7 +1,7 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 2; tab-width: 2 -*- */
 /* geoiplookup.c
  *
- * Copyright (C) 2002 MaxMind.com
+ * Copyright (C) 2004 MaxMind LLC
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -32,6 +32,7 @@ int main (int argc, char *argv[]) {
 	GeoIPRegion * region;
 	GeoIPRecord * gir;
 	const char * org;
+	int netspeed;
 	char * db_info;
 	GeoIP * gi;
 	int i;
@@ -67,7 +68,8 @@ int main (int argc, char *argv[]) {
 					} else {
 						printf("%s: %s, %s\n", GeoIPDBDescription[i], country_code, country_name);
 					}
-				} else if (GEOIP_REGION_EDITION == i) {
+				} else if (GEOIP_REGION_EDITION_REV0 == i ||
+									 GEOIP_REGION_EDITION_REV1 == i) {
 					region = GeoIP_region_by_name(gi, hostname);
 					if (NULL == region) {
 						printf("%s: IP Address not found\n", GeoIPDBDescription[i]);
@@ -97,6 +99,17 @@ int main (int argc, char *argv[]) {
 					} else {
 						printf("%s: %s\n", GeoIPDBDescription[i], org);
 					}
+				} else if (GEOIP_NETSPEED_EDITION == i) {
+					netspeed = GeoIP_id_by_name (gi, hostname);
+					if (netspeed == GEOIP_UNKNOWN_SPEED) {
+						printf("%s: Unknown\n", GeoIPDBDescription[i]);
+					} else if (netspeed == GEOIP_DIALUP_SPEED) {
+						printf("%s: Dialup\n", GeoIPDBDescription[i]);
+					} else if (netspeed == GEOIP_CABLEDSL_SPEED) {
+						printf("%s: Cable/DSL\n", GeoIPDBDescription[i]);
+					} else if (netspeed == GEOIP_CORPORATE_SPEED) {
+						printf("%s: Corporate\n", GeoIPDBDescription[i]);
+					}
 				}
 			}
 			GeoIP_delete(gi);
